PyBaccarat: tests.test_scoreboard Namespace Reference

PyBaccarat visit the ministry of silly walks

Classes | Variables
tests.test_scoreboard Namespace Reference

Unit test for the Card class. More...

## Classes
class | TestScoreboard

## Variables
| HERE = os.path.dirname(os.path.abspath(__file__))

## Detailed Description

Unit test for the Card class.

To execute the unit test from base dir location, enter:

cd pybaccarat_base
python tests\unittest_card.py [-v]
rem Run a single test case
cd C:\git\PyBaccarat
python tests\unittest_scoreboard.py TestScoreboard.test_version

Author
  fulkg.nosp@m.l@gm.nosp@m.ail.c.nosp@m.om